@@ -635,7 +635,6 @@ class TransparentPath(os.PathLike):  # noqa : F811
             return
 
         # In case we initiate a path containing 'gs://'
-        # If True, then path can not be a TransparentPath for a TransparentPath does not contain gs:// anymore
         if "gs://" in str(path):
 
             if project is None and TransparentPath.project is None:
@@ -848,7 +847,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
 
     def __str__(self) -> str:
         """Will not contain gs://, even if the file system is GCS. To get the path with gs://, use self.__fspath__()"""
-        return str(self.__path)
+        return self.__fspath__()
 
     def __repr__(self) -> str:
         return str(self.__path)
@@ -860,7 +859,8 @@ class TransparentPath(os.PathLike):  # noqa : F811
             return "gs://" + str(self.__path)
 
     def __hash__(self) -> int:
-        hash_number = int.from_bytes(self.__fspath__().encode(), 'little') + int.from_bytes(self.fs_kind.encode(), 'little')
+        hash_number = int.from_bytes(self.__fspath__().encode(), 'little')\
+                      + int.from_bytes(self.fs_kind.encode(), 'little')
         if self.fs_kind == "gcs":
             hash_number += int.from_bytes(self.project.encode(), 'little')
         return hash_number
